import wx


class PrimerPanel(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent=parent)
        vbox = wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(vbox)

        hbox1 = wx.BoxSizer(wx.HORIZONTAL)
        hbox2 = wx.BoxSizer(wx.HORIZONTAL)
        hbox3 = wx.BoxSizer(wx.HORIZONTAL)
        hbox4 = wx.BoxSizer(wx.HORIZONTAL)
        hbox5 = wx.BoxSizer(wx.HORIZONTAL)
        hbox6 = wx.BoxSizer(wx.HORIZONTAL)
        hbox7 = wx.BoxSizer(wx.HORIZONTAL)
        hbox8 = wx.BoxSizer(wx.HORIZONTAL)
        hbox9 = wx.BoxSizer(wx.HORIZONTAL)

        st1 = wx.StaticText(self, label='input')
        hbox1.Add(st1, flag=wx.RIGHT, border=8)

        btn_file = wx.Button(self, label='choose file', size=(90, 30))
        hbox1.Add(btn_file, flag=wx.RIGHT, border=8)
        btn_file.Bind(wx.EVT_BUTTON, self.choose_file)

        self.input = wx.TextCtrl(self)
        hbox1.Add(self.input, proportion=1)
        vbox.Add(hbox1, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st2 = wx.StaticText(self, label='output')
        hbox2.Add(st2, flag=wx.RIGHT, border=8)

        btn_file = wx.Button(self, label='choose folder', size=(100, 30))
        hbox2.Add(btn_file, flag=wx.RIGHT, border=8)
        btn_file.Bind(wx.EVT_BUTTON, self.choose_folder_output)

        self.output = wx.TextCtrl(self)
        hbox2.Add(self.output, proportion=1)
        vbox.Add(hbox2, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st3 = wx.StaticText(self, label='length')
        self.length = wx.TextCtrl(self)
        hbox3.Add(st3, flag=wx.RIGHT, border=8)
        hbox3.Add(self.length, proportion=1)
        vbox.Add(hbox3, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st4 = wx.StaticText(self, label='optimum length')
        self.opt = wx.TextCtrl(self)
        hbox4.Add(st4, flag=wx.RIGHT, border=8)
        hbox4.Add(self.opt, proportion=1)
        vbox.Add(hbox4, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st5 = wx.StaticText(self, label='minimum length')
        self.min = wx.TextCtrl(self)
        hbox5.Add(st5, flag=wx.RIGHT, border=8)
        hbox5.Add(self.min, proportion=1)
        vbox.Add(hbox5, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st6 = wx.StaticText(self, label='maximum length')
        self.max = wx.TextCtrl(self)
        hbox6.Add(st6, flag=wx.RIGHT, border=8)
        hbox6.Add(self.max, proportion=1)
        vbox.Add(hbox6, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st7 = wx.StaticText(self, label='optimum temperature (C)')
        self.tm_opt = wx.TextCtrl(self, value='60.0')
        hbox7.Add(st7, flag=wx.RIGHT, border=8)
        hbox7.Add(self.tm_opt, proportion=1)
        vbox.Add(hbox7, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st8 = wx.StaticText(self, label='minimum temperature (C)')
        self.tm_min = wx.TextCtrl(self, value='57.0')
        hbox8.Add(st8, flag=wx.RIGHT, border=8)
        hbox8.Add(self.tm_min, proportion=1)
        vbox.Add(hbox8, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st9 = wx.StaticText(self, label='maximum temperature (C)')
        self.tm_max = wx.TextCtrl(self, value='63.0')
        hbox9.Add(st9, flag=wx.RIGHT, border=8)
        hbox9.Add(self.tm_max, proportion=1)
        vbox.Add(hbox9, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        self.btnRun = wx.Button(self, label='Make primers!', size=(100, 30))
        h_run = wx.BoxSizer(wx.HORIZONTAL)
        h_run.Add(self.btnRun, flag=wx.LEFT, border=10)
        vbox.Add(h_run, flag=wx.ALIGN_RIGHT | wx.BOTTOM | wx.RIGHT, border=10)

        self.btnReturn = wx.Button(self, label='Return to step mapping')
        h_return = wx.BoxSizer(wx.HORIZONTAL)
        h_return.Add(self.btnReturn, flag=wx.EXPAND, border=10)
        vbox.Add(h_return, flag=wx.ALIGN_LEFT | wx.BOTTOM | wx.LEFT, border=10)

    def choose_file(self, event):
        dlg = wx.DirDialog(
            self, message="Choose a file")
        if dlg.ShowModal() == wx.ID_OK:
            paths = dlg.GetPath()
            self.input.SetValue(str(paths))
        dlg.Destroy()

    def choose_folder_output(self, event):
        dlg = wx.DirDialog(
            self, message="Choose a folder")
        if dlg.ShowModal() == wx.ID_OK:
            paths = dlg.GetPath()
            self.output.SetValue(str(paths))
        dlg.Destroy()



import wx
from src.logic import Splitter


class SplitterWindow(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, -1, 'Splitter', size=(600, 300))
        panel = wx.Panel(self)

        vbox = wx.BoxSizer(wx.VERTICAL)
        hbox1 = wx.BoxSizer(wx.HORIZONTAL)
        hbox2 = wx.BoxSizer(wx.HORIZONTAL)
        hbox3 = wx.BoxSizer(wx.HORIZONTAL)
        hbox4 = wx.BoxSizer(wx.HORIZONTAL)

        st1 = wx.StaticText(panel, label='sequence')
        hbox1.Add(st1, flag=wx.RIGHT, border=8)

        btn_file = wx.Button(panel, label='choose file', size=(90, 30))
        hbox1.Add(btn_file, flag=wx.RIGHT, border=8)
        btn_file.Bind(wx.EVT_BUTTON, self.choose_file)

        self.sequence = wx.TextCtrl(panel)
        hbox1.Add(self.sequence, proportion=1)
        vbox.Add(hbox1, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st2 = wx.StaticText(panel, label='length')
        self.length = wx.TextCtrl(panel)
        hbox2.Add(st2, flag=wx.RIGHT, border=8)
        hbox2.Add(self.length, proportion=1)
        vbox.Add(hbox2, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st3 = wx.StaticText(panel, label='interval')
        self.interval = wx.TextCtrl(panel)
        hbox3.Add(st3, flag=wx.RIGHT, border=8)
        hbox3.Add(self.interval, proportion=1)
        vbox.Add(hbox3, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st4 = wx.StaticText(panel, label='output')
        self.output = wx.TextCtrl(panel)
        hbox4.Add(st4, flag=wx.RIGHT, border=8)
        hbox4.Add(self.output, proportion=1)
        vbox.Add(hbox4, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        vbox.Add(wx.Size(50, 50))

        btnRun = wx.Button(panel, label='RUN', size=(70, 30))
        hrun = wx.BoxSizer(wx.HORIZONTAL)
        hrun.Add(btnRun, flag=wx.LEFT, border=10)
        vbox.Add(hrun, flag=wx.ALIGN_RIGHT | wx.BOTTOM | wx.RIGHT, border=10)
        panel.SetSizer(vbox)
        btnRun.Bind(wx.EVT_BUTTON, self.split_sequence)

    def choose_file(self, event):
        dlg = wx.FileDialog(
            self, message="Choose a file")
        if dlg.ShowModal() == wx.ID_OK:
            paths = dlg.GetPath()
            self.sequence.SetValue(str(paths))
        dlg.Destroy()

    def split_sequence(self, event):
        output = self.output.GetValue()
        interval = self.interval.GetValue()
        length = self.length.GetValue()
        sequence = self.sequence.GetValue()
        if output != '' and interval != '' and length != '' and sequence != '':
            Splitter(output, sequence, int(length), int(interval))
        else:
            wx.MessageDialog(None, 'Not enough data', '!', wx.OK).ShowModal()



from .prepare_panel import PreparePanel
from .blast_panel import BlastPanel
from .loading_blast_panel import LoadingBlastPanel
from .mapping_panel import MappingPanel
from .primer_panel import PrimerPanel
from .main_panel import MainPanel



from multiprocessing import Process

import wx
from gui import MainPanel
from gui import PreparePanel
from gui import BlastPanel
from gui import LoadingBlastPanel
from gui import MappingPanel
from gui import PrimerPanel
from src import GenomeMapping
from src import Blast
from src import PrimersMaking
import multiprocessing


class MyFrame(wx.Frame):
    blast_thread = None

    def __init__(self, parent, title):
        super().__init__(parent, title=title, size=(700, 400))

        vbox = wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(vbox)

        self.main_panel = MainPanel(self)
        vbox.Add(self.main_panel, 1, wx.EXPAND)
        self.main_panel.btn_prepare.Bind(wx.EVT_BUTTON, self.open_prepare_panel)
        self.main_panel.btn_blast.Bind(wx.EVT_BUTTON, self.open_blast_panel)
        self.main_panel.btn_primer.Bind(wx.EVT_BUTTON, self.open_primer_panel)

        self.prepare_panel = PreparePanel(self)
        vbox.Add(self.prepare_panel, 1, wx.EXPAND)
        self.prepare_panel.btnRun.Bind(wx.EVT_BUTTON, self.open_blast_panel)
        self.prepare_panel.Hide()
        self.Centre()

        self.blast_panel = BlastPanel(self)
        vbox.Add(self.blast_panel, 1, wx.EXPAND)
        self.blast_panel.btnReturn.Bind(wx.EVT_BUTTON, self.open_prepare_panel)
        self.blast_panel.btnRun.Bind(wx.EVT_BUTTON, self.blast_analise)
        self.blast_panel.Hide()
        self.Centre()

        self.loading_blast_panel = LoadingBlastPanel(self)
        vbox.Add(self.loading_blast_panel, 1, wx.EXPAND)
        self.loading_blast_panel.btnRun.Bind(wx.EVT_BUTTON, self.open_mapping_panel)
        self.loading_blast_panel.btnReturn.Bind(wx.EVT_BUTTON, self.hide_loading_panel)
        self.loading_blast_panel.btnStop.Bind(wx.EVT_BUTTON, self.stop_blast)
        self.loading_blast_panel.Hide()
        self.Centre()

        self.mapping_panel = MappingPanel(self)
        vbox.Add(self.mapping_panel, 1, wx.EXPAND)
        self.mapping_panel.btnRun.Bind(wx.EVT_BUTTON, self.start_mapping)
        self.mapping_panel.btnReturn.Bind(wx.EVT_BUTTON, self.open_blast_panel)
        self.mapping_panel.btnPrimers.Bind(wx.EVT_BUTTON, self.open_primer_panel)
        self.mapping_panel.Hide()
        self.Centre()

        self.primer_panel = PrimerPanel(self)
        vbox.Add(self.primer_panel, 1, wx.EXPAND)
        self.primer_panel.btnRun.Bind(wx.EVT_BUTTON, self.start_primer_making)
        self.primer_panel.btnReturn.Bind(wx.EVT_BUTTON, self.open_mapping_panel)
        self.primer_panel.Hide()
        self.Centre()

        self.Bind(wx.EVT_CLOSE, self.on_close_window)

    def on_close_window(self, event):
        dial = wx.MessageDialog(None, 'Do you want to exit?', '?',
                                wx.YES_NO | wx.NO_DEFAULT | wx.ICON_QUESTION)

        ret = dial.ShowModal()

        if ret == wx.ID_YES:
            self.Destroy()
        else:
            event.Veto()

    def open_blast_panel(self, event):
        self.blast_panel.Show()
        self.main_panel.Hide()
        self.prepare_panel.Hide()
        self.mapping_panel.Hide()
        self.Layout()

    def open_prepare_panel(self, event):
        self.prepare_panel.Show()
        self.main_panel.Hide()
        self.blast_panel.Hide()
        self.Layout()

    def open_mapping_panel(self, event):
        self.mapping_panel.Show()
        self.primer_panel.Hide()
        self.loading_blast_panel.Hide()
        self.Layout()

    def hide_loading_panel(self, event):
        self.blast_thread.terminate()
        self.loading_blast_panel.Hide()
        self.blast_panel.Show()
        self.Layout()

    def open_primer_panel(self, event):
        self.primer_panel.Show()
        self.main_panel.Hide()
        self.mapping_panel.Hide()
        self.Layout()

    def blast_analise(self, event):
        input_data = self.blast_panel.input.GetValue()
        database = self.blast_panel.database.GetValue()
        output = self.blast_panel.output.GetValue()
        e_value = self.blast_panel.evalue.GetValue()
        num_threads = self.blast_panel.num_threads.GetValue()
        task = self.blast_panel.rbox.GetStringSelection()
        file_format = 'fasta'
        if input_data != '' and database != '' and output != '' and e_value != '' and num_threads != '':
            self.loading_blast_panel.Show()
            self.blast_panel.Hide()
            self.Layout()
            self.blast_thread = Process(
                target=Blast,
                args=(input_data, database, output, file_format, e_value, num_threads, task))
            self.blast_thread.start()

        else:
            wx.MessageDialog(None, 'Not enough data', '', wx.OK).ShowModal()

    def stop_blast(self, event):
        self.blast_thread.terminate()

    def start_mapping(self, event):
        input_file = self.mapping_panel.input.GetValue()
        output_folder = self.mapping_panel.output.GetValue()
        if input_file != '' and output_folder != '':
            GenomeMapping(input_file, output_folder)
        else:
            wx.MessageDialog(None, 'Not enough data', '', wx.OK).ShowModal()

    def start_primer_making(self, event):
        input_file = self.primer_panel.input.GetValue()
        output_folder = self.primer_panel.output.GetValue()
        length = self.primer_panel.length.GetValue()
        opt = self.primer_panel.opt.GetValue()
        min = self.primer_panel.min.GetValue()
        max = self.primer_panel.max.GetValue()
        opt_tm = self.primer_panel.tm_opt.GetValue()
        min_tm = self.primer_panel.tm_min.GetValue()
        max_tm = self.primer_panel.tm_max.GetValue()
        if input_file != '' and output_folder != '' and length != '' and opt != '' and \
                min != '' and opt_tm != '' and min_tm != '' and max_tm != '':
            PrimersMaking(input_file, output_folder, int(length), int(opt), int(min), int(max),
                          float(opt_tm), float(min_tm), float(max_tm))
        else:
            wx.MessageDialog(None, 'Not enough data', '', wx.OK).ShowModal()


if __name__ == '__main__':
    multiprocessing.set_start_method('spawn')
    app = wx.App()
    wnd = MyFrame(None, "S3Finder")
    wnd.Show()
    app.MainLoop()



#!/usr/bin/env python
import argparse
from .logic import GenomeMapping


def mapping_genome():
    parser = argparse.ArgumentParser()
    parser.add_argument('--input', dest='input', type=str, help='path to input file', required=True)
    parser.add_argument('--output', dest='output', type=str, default='output', help='path to output folder')
    args = parser.parse_args()
    return args.input, args.output


input, output = mapping_genome()

GenomeMapping(input, output)



import wx


class LoadingBlastPanel(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent=parent)
        vbox = wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(vbox)

        hbox1 = wx.BoxSizer(wx.HORIZONTAL)
        st1 = wx.StaticText(self, label='Blast loading')
        hbox1.Add(st1, flag=wx.ALIGN_CENTER, border=8)
        vbox.Add(hbox1, flag=wx.ALIGN_CENTER, border=10)

        vbox.Add(wx.Size(50, 50))

        self.btnStop = wx.Button(self, label='Stop', size=(70, 30))
        h_stop = wx.BoxSizer(wx.HORIZONTAL)
        h_stop.Add(self.btnStop, flag=wx.ALL | wx.ALIGN_CENTER, border=10)
        vbox.Add(h_stop, flag=wx.ALL | wx.ALIGN_CENTER, border=10)
        self.SetSizer(vbox)

        self.btnRun = wx.Button(self, label='To mapping', size=(100, 30))
        self.btnReturn = wx.Button(self, label='Return')

        h_button = wx.BoxSizer(wx.HORIZONTAL)

        h_button.Add(self.btnReturn, flag=wx.LEFT, border=10)

        h_button.Add(wx.Size(470, 10))
        h_button.Add(self.btnRun, flag=wx.LEFT, border=10)
        vbox.Add(h_button, flag=wx.ALIGN_LEFT | wx.BOTTOM | wx.LEFT, border=10)



from enum import Enum
from multiprocessing import Process

import wx

from src.logic import GenomeDownloader


class State(Enum):
    NOT_STARTED = 1
    PROCESSING = 2
    ERROR = 3


# Окно с программой для закачки геномов
class PrepareWindow(wx.Frame):
    download_thread = None
    state = State.NOT_STARTED

    def __init__(self, parent):
        super().__init__(parent, title='Downloading and making database', size=(600, 450))

        vbox = wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(vbox)

        self.panel_one = DownloadPanel(self)
        vbox.Add(self.panel_one, 1, wx.EXPAND)
        self.panel_one.btnRun.Bind(wx.EVT_BUTTON, self.on_run)

        self.loading_panel = LoadingPanel(self)
        vbox.Add(self.loading_panel, 1, wx.EXPAND)
        self.loading_panel.btnStop.Bind(wx.EVT_BUTTON, self.on_stop)
        self.loading_panel.Hide()
        self.Centre()

        self.Bind(wx.EVT_CLOSE, self.on_close_window)

    def on_close_window(self, event):
        if self.state == State.PROCESSING:
            dial = wx.MessageDialog(None, 'Are you sure you want to abort the process and exit?', '?',
                                    wx.YES_NO | wx.NO_DEFAULT | wx.ICON_QUESTION)

            ret = dial.ShowModal()

            if ret == wx.ID_YES:
                self.Destroy()
            else:
                event.Veto()

        if self.state == State.NOT_STARTED:
            self.Destroy()

    def on_run(self, event):
        output = self.panel_one.output.GetValue()
        genus = self.panel_one.genus.GetValue()
        species = self.panel_one.species.GetValue()
        id = self.panel_one.id.GetValue()
        if output != '' and genus != '' and species != '' and id != '':
            self.state = State.PROCESSING

            self.loading_panel.Show()
            self.panel_one.Hide()
            self.Layout()

            self.download_thread = Process(
                target=GenomeDownloader,
                args=(output, genus, species, id))
            self.download_thread.start()
        else:
            wx.MessageDialog(None, 'Not enough data', '', wx.OK).ShowModal()

    def on_stop(self, event):
        self.state = State.NOT_STARTED

        dial = wx.MessageDialog(None, 'Are you sure you want to abort the process?', 'Вопрос',
                                wx.YES_NO | wx.NO_DEFAULT | wx.ICON_QUESTION)

        ret = dial.ShowModal()

        if ret == wx.ID_YES:
            self.download_thread.terminate()
        else:
            event.Veto()
        self.panel_one.Show()
        self.loading_panel.Hide()
        self.Layout()


class DownloadPanel(wx.Panel):

    def __init__(self, parent):
        wx.Panel.__init__(self, parent=parent)

        vbox = wx.BoxSizer(wx.VERTICAL)
        hbox1 = wx.BoxSizer(wx.HORIZONTAL)
        hbox2 = wx.BoxSizer(wx.HORIZONTAL)
        hbox3 = wx.BoxSizer(wx.HORIZONTAL)
        hbox4 = wx.BoxSizer(wx.HORIZONTAL)
        hbox5 = wx.BoxSizer(wx.HORIZONTAL)
        hbox6 = wx.BoxSizer(wx.HORIZONTAL)

        st1 = wx.StaticText(self, label='genus')
        self.genus = wx.TextCtrl(self)
        hbox1.Add(st1, flag=wx.RIGHT, border=8)
        hbox1.Add(self.genus, proportion=1)
        vbox.Add(hbox1, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st2 = wx.StaticText(self, label='species')
        self.species = wx.TextCtrl(self)
        hbox2.Add(st2, flag=wx.RIGHT, border=8)
        hbox2.Add(self.species, proportion=1)
        vbox.Add(hbox2, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st3 = wx.StaticText(self, label='accession')
        self.id = wx.TextCtrl(self)
        hbox3.Add(st3, flag=wx.RIGHT, border=8)
        hbox3.Add(self.id, proportion=1)
        vbox.Add(hbox3, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st4 = wx.StaticText(self, label='output')
        self.output = wx.TextCtrl(self)
        hbox4.Add(st4, flag=wx.RIGHT, border=8)
        hbox4.Add(self.output, proportion=1)
        vbox.Add(hbox4, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st5 = wx.StaticText(self, label='positive_strain')
        self.positive_strain = wx.TextCtrl(self)
        hbox5.Add(st5, flag=wx.RIGHT, border=8)
        hbox5.Add(self.positive_strain, proportion=1)
        vbox.Add(hbox5, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        st6 = wx.StaticText(self, label='negative_strain')
        self.negative_strain = wx.TextCtrl(self)
        hbox6.Add(st6, flag=wx.RIGHT, border=8)
        hbox6.Add(self.negative_strain, proportion=1)
        vbox.Add(hbox6, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        vbox.Add(wx.Size(50, 50))

        self.btnRun = wx.Button(self, label='RUN', size=(70, 30))
        hrun = wx.BoxSizer(wx.HORIZONTAL)
        hrun.Add(self.btnRun, flag=wx.LEFT, border=10)
        vbox.Add(hrun, flag=wx.ALIGN_RIGHT | wx.BOTTOM | wx.RIGHT, border=10)
        self.SetSizer(vbox)


class LoadingPanel(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent=parent)
        vbox = wx.BoxSizer(wx.VERTICAL)
        hstatus = wx.BoxSizer(wx.HORIZONTAL)

        self.status = wx.StaticText(self, -1, 'Process in progress')

        hstatus.Add(self.status)
        vbox.Add(hstatus, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=1)

        hor = wx.BoxSizer(wx.HORIZONTAL)
        vbox.Add(hor)

        vbox.AddSpacer(50)

        self.btnStop = wx.Button(self, label='Stop', size=(70, 30))
        hstop = wx.BoxSizer(wx.HORIZONTAL)
        hstop.Add(self.btnStop, flag=wx.ALL | wx.ALIGN_CENTER, border=10)
        vbox.Add(hstop, flag=wx.ALL | wx.ALIGN_CENTER, border=10)
        self.SetSizer(vbox)



import wx


class MappingPanel(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent=parent)
        vbox = wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(vbox)

        hbox1 = wx.BoxSizer(wx.HORIZONTAL)
        st1 = wx.StaticText(self, label='input')
        hbox1.Add(st1, flag=wx.RIGHT, border=8)

        btn_file = wx.Button(self, label='choose file', size=(90, 30))
        hbox1.Add(btn_file, flag=wx.RIGHT, border=8)
        btn_file.Bind(wx.EVT_BUTTON, self.choose_file)

        self.input = wx.TextCtrl(self)
        hbox1.Add(self.input, proportion=1)
        vbox.Add(hbox1, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        hbox2 = wx.BoxSizer(wx.HORIZONTAL)
        st3 = wx.StaticText(self, label='output')
        hbox2.Add(st3, flag=wx.RIGHT, border=8)

        btn_file = wx.Button(self, label='choose folder', size=(100, 30))
        hbox2.Add(btn_file, flag=wx.RIGHT, border=8)
        btn_file.Bind(wx.EVT_BUTTON, self.choose_folder_output)

        self.output = wx.TextCtrl(self)
        hbox2.Add(self.output, proportion=1)
        vbox.Add(hbox2, flag=wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, border=10)

        h_run = wx.BoxSizer(wx.HORIZONTAL)
        self.btnRun = wx.Button(self, label='Mapping', size=(70, 30))
        h_run.Add(self.btnRun, flag=wx.LEFT, border=10)
        vbox.Add(h_run, flag=wx.ALIGN_RIGHT | wx.BOTTOM | wx.RIGHT, border=10)
        vbox.Add(wx.Size(30, 200))
        self.btnPrimers = wx.Button(self, label='To making primers', size=(150, 30))
        self.btnReturn = wx.Button(self, label='Return to blast')

        h_button = wx.BoxSizer(wx.HORIZONTAL)

        h_button.Add(self.btnReturn, flag=wx.LEFT | wx.BOTTOM, border=10)

        h_button.Add(wx.Size(400, 10))
        h_button.Add(self.btnPrimers, flag=wx.LEFT | wx.BOTTOM, border=10)
        vbox.Add(h_button, flag=wx.ALIGN_LEFT | wx.BOTTOM, border=10)

    def choose_file(self, event):
        dlg = wx.FileDialog(
            self, message="Choose a file...")
        if dlg.ShowModal() == wx.ID_OK:
            paths = dlg.GetPath()
            self.input.SetValue(str(paths))
        dlg.Destroy()

    def choose_folder_output(self, event):
        dlg = wx.DirDialog(
            self, message="Choose a folder...")
        if dlg.ShowModal() == wx.ID_OK:
            paths = dlg.GetPath()
            self.output.SetValue(str(paths))
        dlg.Destroy()



from Bio import SeqIO


class Splitter:
    def __init__(self, output, sequence, length, interval):

        output_file = open(output + '.fna', 'w')

        with open(sequence) as handle:
            for record in SeqIO.parse(handle, "fasta"):
                for i in range(0, len(record.seq), interval):

                    id_with_interval = record.id + '_' + str(i + 1) + '-' + str(i + length + 1)
                    description = '>' + record.description.replace(record.id, id_with_interval) + '\n'

                    if i + length < len(record.seq):
                        output_file.write(description + str(record.seq[i:i + length]) + '\n')

                    else:
                        output_file.write(description + str(record.seq[-length:]))
                        break



import os
import subprocess
from Bio import SeqIO
import requests
import glob
import ncbi_genome_download as ngd


class GenomeDownloader:
    def __init__(self, output, genus, species, id):
        log = print

        # Make folder for algorithm
        if not os.path.exists(output):
            os.mkdir(output)

        ncbi_target_output_folder = output + '/' + genus + '_' + species

        log('Downloading all genomes of target species')

        ngd.download(section='genbank', genera=genus + ' ' + species, groups='bacteria', file_formats='fasta',
                     output=ncbi_target_output_folder, flat_output=True)

        type_strain_folder = output + '/' + 'type_strain'
        if not os.path.exists(type_strain_folder):
            os.mkdir(type_strain_folder)

        log('Unzipping files')

        unzip_command = ['gunzip', '-r', ncbi_target_output_folder]
        subprocess.call(unzip_command)

        list_of_unzip_files = os.listdir(ncbi_target_output_folder)

        for file_name in list_of_unzip_files:
            path_to_file = ncbi_target_output_folder + '/' + file_name

            # Transfer of the file write genome of type strain in other folder
            records = SeqIO.parse(path_to_file, 'fasta')
            for record in records:
                if record.id == id:
                    os.rename(path_to_file, type_strain_folder + '/' + file_name)

        log('Making POSITIVE data base')

        database_folder = output + '/database_' + species

        if not os.path.exists(database_folder):
            os.mkdir(database_folder)

        files = ' '.join(glob.glob(ncbi_target_output_folder + "/*.fna"))
        path_to_database = database_folder + '/' + species
        make_db = ['makeblastdb', '-in', files, '-out', path_to_database, '-title', species, '-dbtype', 'nucl',
                   '-parse_seqids']
        subprocess.call(make_db)

        log('Getting genus info by API NCBI')

        genus_info = requests.get('https://api.ncbi.nlm.nih.gov/datasets/v1alpha/genome/taxon/' + genus + '/tree')

        others_list = []
        for _species in genus_info.json()['children']:
            others_list.append(_species['sci_name'].lower())
        others_list.remove(genus.lower() + ' ' + species.lower())

        log('Downloading all genomes of others species for target genus')

        ncbi_others_output_folder = output + '/' + 'others'
        ngd.download(section='genbank', genera=','.join(others_list), groups='bacteria', file_formats='fasta',
                     output=ncbi_others_output_folder,
                     flat_output=True)

        log('Unzipping files')

        unzip_command = ['gunzip', '-r', ncbi_others_output_folder]
        subprocess.call(unzip_command)

        log('Making NEGATIVE data base')

        database_folder = output + '/database_others'

        if not os.path.exists(database_folder):
            os.mkdir(database_folder)

        files = ' '.join(glob.glob(ncbi_others_output_folder + "/*.fna"))
        path_to_database = database_folder + '/others'
        make_db = ['makeblastdb', '-in', files, '-out', path_to_database, '-title', 'others_species', '-dbtype', 'nucl',
                   '-parse_seqids']
        subprocess.call(make_db)

        log('Complete!')
